{ config
, lib
, pkgs
, ... 
}:

let
  unstablepkgs = import <nixos-unstable> {};

in rec {
  # The NixOS release to be compatible with for stateful data such as databases.
  # system.stateVersion = "unstable";

  networking.hostName = "steveej-laptop"; # Define your hostname.

  # Used for testing local Tectonic clusters
  environment.etc."NetworkManager/dnsmasq.d/tectonic.conf".text = ''
    server=/tt.testing/192.168.124.1
    server=/tectonic-ci.de/192.168.124.1
    server=/tectonic-ci.lan/192.168.124.1
  '';
  networking.firewall.checkReversePath = false;

  networking.bridges."virbr1".interfaces = [];
  networking.interfaces."virbr1".ipv4.addresses = [
      { address = "10.254.254.254"; prefixLength = 24; }
  ];

  services.printing = {
    enable = true;
    drivers = [
      pkgs.hplip
      unstablepkgs.cups-kyodialog3
      unstablepkgs.mfcj6510dwlpr
      unstablepkgs.mfcj6510dw-cupswrapper
    ];
  };

  services.nix-serve.enable = true;

  services.fprintd.enable = true;
  security.pam.services = {
    login.fprintAuth = true;
    sudo.fprintAuth = true;
  };

  # Kubernetes
  # services.kubernetes.roles = ["master" "node"];

  # virtualization
  virtualisation = {
    libvirtd.enable = true;
    virtualbox.host.enable = true;
    virtualbox.host.addNetworkInterface = true;
    docker.enable = true;
  };
}
